/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/clos/streams.lsp                    */
#include <ecl/ecl-cmp.h>
#include "clos/streams.eclh"
/* function definition for BUG-OR-ERROR                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L2437bug_or_error(cl_object v1stream, cl_object v2fun)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(cl_streamp(v1stream))){
  goto L2;
 }
 value0 = cl_error(3, VV[5], v1stream, v2fun);
 return value0;
L2:;
 value0 = cl_error(5, ECL_SYM("TYPE-ERROR",873), ECL_SYM("DATUM",1245), v1stream, ECL_SYM("EXPECTED-TYPE",1263), ECL_SYM("STREAM",802));
 return value0;
}
/* local function STREAM-ADVANCE-TO-COLUMN                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2438stream_advance_to_column(cl_object v1stream, cl_object v2column)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3current_column;
  v3current_column = (cl_env_copy->function=ecl_fdefinition(ECL_SYM("STREAM-LINE-COLUMN",1706)))->cfun.entry(1, v1stream) /*  STREAM-LINE-COLUMN */;
  if (Null(v3current_column)){
   goto L3;
  }
  {
   cl_object v4fill;
   T0 = ecl_minus(v2column,v3current_column);
   v4fill = ecl_floor1(T0);
   {
    cl_object v5i;
    v5i = ecl_make_int8_t(0);
    goto L9;
L8:;
    (cl_env_copy->function=ecl_fdefinition(ECL_SYM("STREAM-WRITE-CHAR",1721)))->cfun.entry(2, v1stream, ECL_CODE_CHAR(32)) /*  STREAM-WRITE-CHAR */;
    v5i = ecl_one_plus(v5i);
L9:;
    if (!(ecl_lower(v5i,v4fill))){
     goto L14;
    }
    goto L8;
L14:;
   }
  }
  value0 = ECL_T;
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC2438stream_advance_to_column_va(cl_narg narg, cl_object v4stream, cl_object v5column, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(ECL_SYM("STREAM-ADVANCE-TO-COLUMN",1694));
 {
  return LC2438stream_advance_to_column(v4stream, v5column);
 }
}
/* local function STREAM-CLEAR-INPUT                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2439stream_clear_input(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2439stream_clear_input_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-CLEAR-INPUT",1695));
 {
  return LC2439stream_clear_input(v2stream);
 }
}
/* local function STREAM-CLEAR-INPUT                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2440stream_clear_input(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_clear_input(1, v1stream);
 return value0;
}
static cl_object LC2440stream_clear_input_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-CLEAR-INPUT",1695));
 {
  return LC2440stream_clear_input(v2stream);
 }
}
/* local function STREAM-CLEAR-INPUT                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2441stream_clear_input(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L2437bug_or_error(v1stream, ECL_SYM("STREAM-CLEAR-INPUT",1695));
 return value0;
}
static cl_object LC2441stream_clear_input_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-CLEAR-INPUT",1695));
 {
  return LC2441stream_clear_input(v2stream);
 }
}
/* local function STREAM-CLEAR-OUTPUT                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2442stream_clear_output(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2442stream_clear_output_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-CLEAR-OUTPUT",1696));
 {
  return LC2442stream_clear_output(v2stream);
 }
}
/* local function STREAM-CLEAR-OUTPUT                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2443stream_clear_output(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_clear_output(1, v1stream);
 return value0;
}
static cl_object LC2443stream_clear_output_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-CLEAR-OUTPUT",1696));
 {
  return LC2443stream_clear_output(v2stream);
 }
}
/* local function STREAM-CLEAR-OUTPUT                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2444stream_clear_output(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L2437bug_or_error(v1stream, ECL_SYM("STREAM-CLEAR-OUTPUT",1696));
 return value0;
}
static cl_object LC2444stream_clear_output_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-CLEAR-OUTPUT",1696));
 {
  return LC2444stream_clear_output(v2stream);
 }
}
/* local function CLOSE                                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2445close(cl_narg narg, cl_object v1stream, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(ECL_SYM("CLOSE",1689));
 {
  cl_object v2abort;
  ecl_va_list args; ecl_va_start(args,v1stream,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,LC2445closekeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v2abort = keyvars[0];
  }
  (cl_env_copy->function=ecl_fdefinition(VV[7]))->cfun.entry(2, ECL_NIL, v1stream) /*  (SETF OPEN-STREAM-P) */;
  value0 = ECL_T;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* local function CLOSE                                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2446close(cl_narg narg, cl_object v1stream, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(ECL_SYM("CLOSE",1689));
 {
  cl_object v2abort;
  ecl_va_list args; ecl_va_start(args,v1stream,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,LC2446closekeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v2abort = keyvars[0];
  }
  value0 = cl_close(3, v1stream, ECL_SYM("ABORT",1225), v2abort);
  return value0;
 }
}
/* local function CLOSE                                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2447close(cl_narg narg, cl_object v1stream, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(ECL_SYM("CLOSE",1689));
 {
  cl_object v2abort;
  ecl_va_list args; ecl_va_start(args,v1stream,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,LC2447closekeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v2abort = keyvars[0];
  }
  value0 = L2437bug_or_error(v1stream, ECL_SYM("CLOSE",1689));
  return value0;
 }
}
/* local function STREAM-ELEMENT-TYPE                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2448stream_element_type(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_SYM("CHARACTER",224);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2448stream_element_type_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-ELEMENT-TYPE",1697));
 {
  return LC2448stream_element_type(v2stream);
 }
}
/* local function STREAM-ELEMENT-TYPE                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2449stream_element_type(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_stream_element_type(v1stream);
 return value0;
}
static cl_object LC2449stream_element_type_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-ELEMENT-TYPE",1697));
 {
  return LC2449stream_element_type(v2stream);
 }
}
/* local function STREAM-ELEMENT-TYPE                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2450stream_element_type(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L2437bug_or_error(v1stream, ECL_SYM("STREAM-ELEMENT-TYPE",1697));
 return value0;
}
static cl_object LC2450stream_element_type_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-ELEMENT-TYPE",1697));
 {
  return LC2450stream_element_type(v2stream);
 }
}
/* local function STREAM-FINISH-OUTPUT                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2451stream_finish_output(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2451stream_finish_output_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-FINISH-OUTPUT",1702));
 {
  return LC2451stream_finish_output(v2stream);
 }
}
/* local function STREAM-FINISH-OUTPUT                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2452stream_finish_output(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_finish_output(1, v1stream);
 return value0;
}
static cl_object LC2452stream_finish_output_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-FINISH-OUTPUT",1702));
 {
  return LC2452stream_finish_output(v2stream);
 }
}
/* local function STREAM-FINISH-OUTPUT                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2453stream_finish_output(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L2437bug_or_error(v1stream, ECL_SYM("STREAM-FINISH-OUTPUT",1702));
 return value0;
}
static cl_object LC2453stream_finish_output_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-FINISH-OUTPUT",1702));
 {
  return LC2453stream_finish_output(v2stream);
 }
}
/* local function STREAM-FORCE-OUTPUT                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2454stream_force_output(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2454stream_force_output_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-FORCE-OUTPUT",1703));
 {
  return LC2454stream_force_output(v2stream);
 }
}
/* local function STREAM-FORCE-OUTPUT                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2455stream_force_output(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_force_output(1, v1stream);
 return value0;
}
static cl_object LC2455stream_force_output_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-FORCE-OUTPUT",1703));
 {
  return LC2455stream_force_output(v2stream);
 }
}
/* local function STREAM-FORCE-OUTPUT                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2456stream_force_output(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L2437bug_or_error(v1stream, ECL_SYM("STREAM-FORCE-OUTPUT",1703));
 return value0;
}
static cl_object LC2456stream_force_output_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-FORCE-OUTPUT",1703));
 {
  return LC2456stream_force_output(v2stream);
 }
}
/* local function STREAM-FRESH-LINE                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2457stream_fresh_line(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if ((cl_env_copy->function=ecl_fdefinition(ECL_SYM("STREAM-START-LINE-P",1716)))->cfun.entry(1, v1stream) /*  STREAM-START-LINE-P */!=ECL_NIL) {
  goto L2;
 }
 (cl_env_copy->function=ecl_fdefinition(ECL_SYM("STREAM-TERPRI",1717)))->cfun.entry(1, v1stream) /*  STREAM-TERPRI */;
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2457stream_fresh_line_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-FRESH-LINE",1704));
 {
  return LC2457stream_fresh_line(v2stream);
 }
}
/* local function STREAM-FRESH-LINE                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2458stream_fresh_line(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_fresh_line(1, v1stream);
 return value0;
}
static cl_object LC2458stream_fresh_line_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-FRESH-LINE",1704));
 {
  return LC2458stream_fresh_line(v2stream);
 }
}
/* local function INPUT-STREAM-P                                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2459input_stream_p(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2459input_stream_p_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("INPUT-STREAM-P",1691));
 {
  return LC2459input_stream_p(v2stream);
 }
}
/* local function INPUT-STREAM-P                                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2460input_stream_p(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2460input_stream_p_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("INPUT-STREAM-P",1691));
 {
  return LC2460input_stream_p(v2stream);
 }
}
/* local function INPUT-STREAM-P                                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2461input_stream_p(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_input_stream_p(v1stream);
 return value0;
}
static cl_object LC2461input_stream_p_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("INPUT-STREAM-P",1691));
 {
  return LC2461input_stream_p(v2stream);
 }
}
/* local function INPUT-STREAM-P                                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2462input_stream_p(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L2437bug_or_error(v1stream, ECL_SYM("INPUT-STREAM-P",1691));
 return value0;
}
static cl_object LC2462input_stream_p_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("INPUT-STREAM-P",1691));
 {
  return LC2462input_stream_p(v2stream);
 }
}
/* local function STREAM-INTERACTIVE-P                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2463stream_interactive_p(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2463stream_interactive_p_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-INTERACTIVE-P",1705));
 {
  return LC2463stream_interactive_p(v2stream);
 }
}
/* local function STREAM-INTERACTIVE-P                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2464stream_interactive_p(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_interactive_stream_p(v1stream);
 return value0;
}
static cl_object LC2464stream_interactive_p_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-INTERACTIVE-P",1705));
 {
  return LC2464stream_interactive_p(v2stream);
 }
}
/* local function STREAM-INTERACTIVE-P                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2465stream_interactive_p(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L2437bug_or_error(v1stream, ECL_SYM("STREAM-INTERACTIVE-P",1705));
 return value0;
}
static cl_object LC2465stream_interactive_p_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-INTERACTIVE-P",1705));
 {
  return LC2465stream_interactive_p(v2stream);
 }
}
/* local function STREAM-LINE-COLUMN                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2466stream_line_column(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2466stream_line_column_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-LINE-COLUMN",1706));
 {
  return LC2466stream_line_column(v2stream);
 }
}
/* local function STREAM-LINE-LENGTH                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2467stream_line_length(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2467stream_line_length_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-LINE-LENGTH",1707));
 {
  return LC2467stream_line_length(v2stream);
 }
}
/* local function STREAM-LINE-LENGTH                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2468stream_line_length(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2468stream_line_length_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-LINE-LENGTH",1707));
 {
  return LC2468stream_line_length(v2stream);
 }
}
/* local function STREAM-LINE-LENGTH                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2469stream_line_length(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L2437bug_or_error(v1stream, ECL_SYM("STREAM-LINE-LENGTH",1707));
 return value0;
}
static cl_object LC2469stream_line_length_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-LINE-LENGTH",1707));
 {
  return LC2469stream_line_length(v2stream);
 }
}
/* local function STREAM-LISTEN                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2470stream_listen(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2char;
  v2char = (cl_env_copy->function=ecl_fdefinition(ECL_SYM("STREAM-READ-CHAR-NO-HANG",1713)))->cfun.entry(1, v1stream) /*  STREAM-READ-CHAR-NO-HANG */;
  if (!(ECL_CHARACTERP(v2char))){
   goto L3;
  }
  (cl_env_copy->function=ecl_fdefinition(ECL_SYM("STREAM-UNREAD-CHAR",1719)))->cfun.entry(2, v1stream, v2char) /*  STREAM-UNREAD-CHAR */;
  value0 = ECL_T;
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC2470stream_listen_va(cl_narg narg, cl_object v3stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-LISTEN",1708));
 {
  return LC2470stream_listen(v3stream);
 }
}
/* local function STREAM-LISTEN                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2471stream_listen(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_listen(1, v1stream);
 return value0;
}
static cl_object LC2471stream_listen_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-LISTEN",1708));
 {
  return LC2471stream_listen(v2stream);
 }
}
/* local function STREAM-LISTEN                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2472stream_listen(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L2437bug_or_error(v1stream, ECL_SYM("STREAM-LISTEN",1708));
 return value0;
}
static cl_object LC2472stream_listen_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-LISTEN",1708));
 {
  return LC2472stream_listen(v2stream);
 }
}
/* local function OPEN-STREAM-P                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2473open_stream_p(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_open_stream_p(v1stream);
 return value0;
}
static cl_object LC2473open_stream_p_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("OPEN-STREAM-P",1693));
 {
  return LC2473open_stream_p(v2stream);
 }
}
/* local function OPEN-STREAM-P                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2474open_stream_p(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L2437bug_or_error(v1stream, ECL_SYM("OPEN-STREAM-P",1693));
 return value0;
}
static cl_object LC2474open_stream_p_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("OPEN-STREAM-P",1693));
 {
  return LC2474open_stream_p(v2stream);
 }
}
/* local function OUTPUT-STREAM-P                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2475output_stream_p(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2475output_stream_p_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("OUTPUT-STREAM-P",1692));
 {
  return LC2475output_stream_p(v2stream);
 }
}
/* local function OUTPUT-STREAM-P                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2476output_stream_p(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2476output_stream_p_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("OUTPUT-STREAM-P",1692));
 {
  return LC2476output_stream_p(v2stream);
 }
}
/* local function OUTPUT-STREAM-P                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2477output_stream_p(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_output_stream_p(v1stream);
 return value0;
}
static cl_object LC2477output_stream_p_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("OUTPUT-STREAM-P",1692));
 {
  return LC2477output_stream_p(v2stream);
 }
}
/* local function OUTPUT-STREAM-P                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2478output_stream_p(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L2437bug_or_error(v1stream, ECL_SYM("OUTPUT-STREAM-P",1692));
 return value0;
}
static cl_object LC2478output_stream_p_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("OUTPUT-STREAM-P",1692));
 {
  return LC2478output_stream_p(v2stream);
 }
}
/* local function STREAM-PEEK-BYTE                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2479stream_peek_byte(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2byte;
  v2byte = (cl_env_copy->function=ecl_fdefinition(ECL_SYM("STREAM-READ-BYTE",1711)))->cfun.entry(1, v1stream) /*  STREAM-READ-BYTE */;
  if ((v2byte)==(ECL_SYM("EOF",1259))) {
   goto L3;
  }
  (cl_env_copy->function=ecl_fdefinition(ECL_SYM("STREAM-UNREAD-BYTE",1718)))->cfun.entry(2, v1stream, v2byte) /*  STREAM-UNREAD-BYTE */;
L3:;
  value0 = v2byte;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC2479stream_peek_byte_va(cl_narg narg, cl_object v3stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-PEEK-BYTE",1709));
 {
  return LC2479stream_peek_byte(v3stream);
 }
}
/* local function STREAM-PEEK-BYTE                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2480stream_peek_byte(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = si_peek_byte(v1stream, ECL_SYM("EOF",1259));
 return value0;
}
static cl_object LC2480stream_peek_byte_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-PEEK-BYTE",1709));
 {
  return LC2480stream_peek_byte(v2stream);
 }
}
/* local function STREAM-PEEK-BYTE                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2481stream_peek_byte(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L2437bug_or_error(v1stream, ECL_SYM("STREAM-PEEK-BYTE",1709));
 return value0;
}
static cl_object LC2481stream_peek_byte_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-PEEK-BYTE",1709));
 {
  return LC2481stream_peek_byte(v2stream);
 }
}
/* local function STREAM-PEEK-CHAR                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2482stream_peek_char(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2char;
  v2char = (cl_env_copy->function=ecl_fdefinition(ECL_SYM("STREAM-READ-CHAR",1712)))->cfun.entry(1, v1stream) /*  STREAM-READ-CHAR */;
  if ((v2char)==(ECL_SYM("EOF",1259))) {
   goto L3;
  }
  (cl_env_copy->function=ecl_fdefinition(ECL_SYM("STREAM-UNREAD-CHAR",1719)))->cfun.entry(2, v1stream, v2char) /*  STREAM-UNREAD-CHAR */;
L3:;
  value0 = v2char;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC2482stream_peek_char_va(cl_narg narg, cl_object v3stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-PEEK-CHAR",1710));
 {
  return LC2482stream_peek_char(v3stream);
 }
}
/* local function STREAM-PEEK-CHAR                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2483stream_peek_char(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_peek_char(1, v1stream);
 return value0;
}
static cl_object LC2483stream_peek_char_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-PEEK-CHAR",1710));
 {
  return LC2483stream_peek_char(v2stream);
 }
}
/* local function STREAM-PEEK-CHAR                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2484stream_peek_char(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L2437bug_or_error(v1stream, ECL_SYM("STREAM-PEEK-CHAR",1710));
 return value0;
}
static cl_object LC2484stream_peek_char_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-PEEK-CHAR",1710));
 {
  return LC2484stream_peek_char(v2stream);
 }
}
/* local function STREAM-READ-BYTE                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2485stream_read_byte(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_read_byte(1, v1stream);
 return value0;
}
static cl_object LC2485stream_read_byte_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-READ-BYTE",1711));
 {
  return LC2485stream_read_byte(v2stream);
 }
}
/* local function STREAM-READ-BYTE                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2486stream_read_byte(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L2437bug_or_error(v1stream, ECL_SYM("STREAM-READ-BYTE",1711));
 return value0;
}
static cl_object LC2486stream_read_byte_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-READ-BYTE",1711));
 {
  return LC2486stream_read_byte(v2stream);
 }
}
/* local function STREAM-READ-CHAR                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2487stream_read_char(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_read_char(1, v1stream);
 return value0;
}
static cl_object LC2487stream_read_char_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-READ-CHAR",1712));
 {
  return LC2487stream_read_char(v2stream);
 }
}
/* local function STREAM-READ-CHAR                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2488stream_read_char(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L2437bug_or_error(v1stream, ECL_SYM("STREAM-READ-CHAR",1712));
 return value0;
}
static cl_object LC2488stream_read_char_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-READ-CHAR",1712));
 {
  return LC2488stream_read_char(v2stream);
 }
}
/* local function STREAM-UNREAD-BYTE                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2489stream_unread_byte(cl_object v1stream, cl_object v2byte)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = si_unread_byte(v1stream, v2byte);
 return value0;
}
static cl_object LC2489stream_unread_byte_va(cl_narg narg, cl_object v3stream, cl_object v4byte, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(ECL_SYM("STREAM-UNREAD-BYTE",1718));
 {
  return LC2489stream_unread_byte(v3stream, v4byte);
 }
}
/* local function STREAM-UNREAD-BYTE                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2490stream_unread_byte(cl_object v1stream, cl_object v2byte)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L2437bug_or_error(v1stream, ECL_SYM("STREAM-UNREAD-BYTE",1718));
 return value0;
}
static cl_object LC2490stream_unread_byte_va(cl_narg narg, cl_object v3stream, cl_object v4byte, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(ECL_SYM("STREAM-UNREAD-BYTE",1718));
 {
  return LC2490stream_unread_byte(v3stream, v4byte);
 }
}
/* local function STREAM-UNREAD-CHAR                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2491stream_unread_char(cl_object v1stream, cl_object v2character)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_unread_char(2, v2character, v1stream);
 return value0;
}
static cl_object LC2491stream_unread_char_va(cl_narg narg, cl_object v3stream, cl_object v4character, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(ECL_SYM("STREAM-UNREAD-CHAR",1719));
 {
  return LC2491stream_unread_char(v3stream, v4character);
 }
}
/* local function STREAM-UNREAD-CHAR                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2492stream_unread_char(cl_object v1stream, cl_object v2character)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L2437bug_or_error(v1stream, ECL_SYM("STREAM-UNREAD-CHAR",1719));
 return value0;
}
static cl_object LC2492stream_unread_char_va(cl_narg narg, cl_object v3stream, cl_object v4character, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(ECL_SYM("STREAM-UNREAD-CHAR",1719));
 {
  return LC2492stream_unread_char(v3stream, v4character);
 }
}
/* local function STREAM-READ-CHAR-NO-HANG                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2493stream_read_char_no_hang(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(ECL_SYM("STREAM-READ-CHAR",1712)))->cfun.entry(1, v1stream) /*  STREAM-READ-CHAR */;
 return value0;
}
static cl_object LC2493stream_read_char_no_hang_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-READ-CHAR-NO-HANG",1713));
 {
  return LC2493stream_read_char_no_hang(v2stream);
 }
}
/* local function STREAM-READ-CHAR-NO-HANG                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2494stream_read_char_no_hang(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_read_char_no_hang(1, v1stream);
 return value0;
}
static cl_object LC2494stream_read_char_no_hang_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-READ-CHAR-NO-HANG",1713));
 {
  return LC2494stream_read_char_no_hang(v2stream);
 }
}
/* local function STREAM-READ-CHAR-NO-HANG                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2495stream_read_char_no_hang(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L2437bug_or_error(v1stream, ECL_SYM("STREAM-READ-CHAR-NO-HANG",1713));
 return value0;
}
static cl_object LC2495stream_read_char_no_hang_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-READ-CHAR-NO-HANG",1713));
 {
  return LC2495stream_read_char_no_hang(v2stream);
 }
}
/* local function STREAM-READ-LINE                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2496stream_read_line(cl_object v1stream)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  cl_object v3res;
  cl_object v4len;
  cl_object v5index;
  v2 = cl_make_string(1, ecl_make_int8_t(80));
  v3res = v2;
  v4len = ecl_make_int8_t(80);
  v5index = ecl_make_int8_t(0);
L6:;
  {
   cl_object v6ch;
   v6ch = (cl_env_copy->function=ecl_fdefinition(ECL_SYM("STREAM-READ-CHAR",1712)))->cfun.entry(1, v1stream) /*  STREAM-READ-CHAR */;
   if (!((v6ch)==(ECL_SYM("EOF",1259)))){
    goto L9;
   }
   T0 = (cl_env_copy->function=(ECL_SYM("SHRINK-VECTOR",1883)->symbol.gfdef))->cfun.entry(2, v3res, v5index) /*  SHRINK-VECTOR */;
   cl_env_copy->nvalues = 2;
   cl_env_copy->values[1] = ECL_T;
   cl_env_copy->values[0] = T0;
   return cl_env_copy->values[0];
L9:;
   if (!(ecl_char_code(v6ch)==ecl_char_code(ECL_CODE_CHAR(10)))){
    goto L11;
   }
   T0 = (cl_env_copy->function=(ECL_SYM("SHRINK-VECTOR",1883)->symbol.gfdef))->cfun.entry(2, v3res, v5index) /*  SHRINK-VECTOR */;
   cl_env_copy->nvalues = 2;
   cl_env_copy->values[1] = ECL_NIL;
   cl_env_copy->values[0] = T0;
   return cl_env_copy->values[0];
L11:;
   if (!(ecl_number_equalp(v5index,v4len))){
    goto L13;
   }
   v4len = ecl_times(v4len,ecl_make_int8_t(2));
   {
    cl_object v7new;
    v7new = cl_make_string(1, v4len);
    cl_replace(2, v7new, v3res);
    v3res = v7new;
   }
L13:;
   ecl_elt_set(v3res,ecl_to_size(v5index),v6ch);
   v5index = ecl_plus(v5index,ecl_make_int8_t(1));
  }
  goto L6;
 }
}
static cl_object LC2496stream_read_line_va(cl_narg narg, cl_object v6stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-READ-LINE",1714));
 {
  return LC2496stream_read_line(v6stream);
 }
}
/* local function STREAM-READ-LINE                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2497stream_read_line(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_read_line(1, v1stream);
 return value0;
}
static cl_object LC2497stream_read_line_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-READ-LINE",1714));
 {
  return LC2497stream_read_line(v2stream);
 }
}
/* local function STREAM-READ-LINE                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2498stream_read_line(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L2437bug_or_error(v1stream, ECL_SYM("STREAM-READ-LINE",1714));
 return value0;
}
static cl_object LC2498stream_read_line_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-READ-LINE",1714));
 {
  return LC2498stream_read_line(v2stream);
 }
}
/* function definition for CLOS-DEFAULT-READ-SEQUENCE                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L2499clos_default_read_sequence(cl_object v1stream, cl_object v2sequence, cl_object v3start, cl_object v4end)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (ecl_unlikely(!(ECL_LISTP(v2sequence) || ECL_VECTORP(v2sequence))))
           FEtype_error_sequence(v2sequence);
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 0;
 {
  bool v5;
  v5 = ECL_FIXNUMP(v3start);
  if (ecl_unlikely(!(v5)))
         FEwrong_type_argument(ECL_SYM("FIXNUM",374),v3start);
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 0;
 }
 {
  cl_fixnum v5;
  cl_object v6;
  {
   cl_object v7;
   value0 = v4end;
   if (value0!=ECL_NIL) {
    goto L7;
   }
   v7 = ecl_make_fixnum(ecl_length(v2sequence));
   goto L5;
L7:;
   v7 = value0;
   goto L5;
L5:;
   {
    bool v8;
    v8 = ECL_FIXNUMP(v7);
    if (ecl_unlikely(!(v8)))
         FEwrong_type_argument(ECL_SYM("FIXNUM",374),v7);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
   }
   v5 = ecl_fixnum(v7);
  }
  v6 = (cl_env_copy->function=ecl_fdefinition(ECL_SYM("STREAM-ELEMENT-TYPE",1697)))->cfun.entry(1, v1stream) /*  STREAM-ELEMENT-TYPE */;
  if ((v6)==(ECL_SYM("CHARACTER",224))) {
   goto L13;
  }
  if (!((v6)==(ECL_SYM("BASE-CHAR",122)))){
   goto L11;
  }
  goto L12;
L13:;
L12:;
  {
   cl_object v7pos;
   v7pos = v3start;
L16:;
   if (!(ecl_greatereq(v7pos,ecl_make_fixnum(v5)))){
    goto L18;
   }
   goto L17;
L18:;
   {
    cl_object v8c;
    v8c = (cl_env_copy->function=ecl_fdefinition(ECL_SYM("STREAM-READ-CHAR",1712)))->cfun.entry(1, v1stream) /*  STREAM-READ-CHAR */;
    if (!((v8c)==(ECL_SYM("EOF",1259)))){
     goto L22;
    }
    value0 = v7pos;
    cl_env_copy->nvalues = 1;
    return value0;
L22:;
    ecl_elt_set(v2sequence,ecl_to_size(v7pos),v8c);
   }
   v7pos = ecl_one_plus(v7pos);
   goto L16;
L17:;
   value0 = v7pos;
   cl_env_copy->nvalues = 1;
   return value0;
  }
L11:;
  {
   cl_object v8pos;
   v8pos = v3start;
L29:;
   if (!(ecl_greatereq(v8pos,ecl_make_fixnum(v5)))){
    goto L31;
   }
   goto L30;
L31:;
   {
    cl_object v9b;
    v9b = (cl_env_copy->function=ecl_fdefinition(ECL_SYM("STREAM-READ-BYTE",1711)))->cfun.entry(1, v1stream) /*  STREAM-READ-BYTE */;
    if (!((v9b)==(ECL_SYM("EOF",1259)))){
     goto L35;
    }
    value0 = v8pos;
    cl_env_copy->nvalues = 1;
    return value0;
L35:;
    ecl_elt_set(v2sequence,ecl_to_size(v8pos),v9b);
   }
   v8pos = ecl_one_plus(v8pos);
   goto L29;
L30:;
   value0 = v8pos;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L2499clos_default_read_sequence_va(cl_narg narg, cl_object v9stream, cl_object v10sequence, cl_object v11start, cl_object v12end, ...)
{
 if (ecl_unlikely(narg!=4)) FEwrong_num_arguments(VV[9]);
 {
  return L2499clos_default_read_sequence(v9stream, v10sequence, v11start, v12end);
 }
}
/* local function STREAM-READ-SEQUENCE                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2500stream_read_sequence(cl_narg narg, cl_object v1stream, cl_object v2sequence, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(ECL_SYM("STREAM-READ-SEQUENCE",1715));
 if (ecl_unlikely(narg>4)) FEwrong_num_arguments(ECL_SYM("STREAM-READ-SEQUENCE",1715));
 {
  cl_object v3start;
  cl_object v4end;
  va_list args; va_start(args,v2sequence);
  {
   int i = 2;
   if (i >= narg) {
    v3start = ecl_make_int8_t(0);
   } else {
    i++;
    v3start = va_arg(args,cl_object);
   }
   if (i >= narg) {
    v4end = ECL_NIL;
   } else {
    i++;
    v4end = va_arg(args,cl_object);
   }
  }
  va_end(args);
  value0 = L2499clos_default_read_sequence(v1stream, v2sequence, v3start, v4end);
  return value0;
 }
}
/* local function STREAM-READ-SEQUENCE                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2501stream_read_sequence(cl_narg narg, cl_object v1stream, cl_object v2sequence, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(ECL_SYM("STREAM-READ-SEQUENCE",1715));
 if (ecl_unlikely(narg>4)) FEwrong_num_arguments(ECL_SYM("STREAM-READ-SEQUENCE",1715));
 {
  cl_object v3start;
  cl_object v4end;
  va_list args; va_start(args,v2sequence);
  {
   int i = 2;
   if (i >= narg) {
    v3start = ecl_make_int8_t(0);
   } else {
    i++;
    v3start = va_arg(args,cl_object);
   }
   if (i >= narg) {
    v4end = ECL_NIL;
   } else {
    i++;
    v4end = va_arg(args,cl_object);
   }
  }
  va_end(args);
  value0 = L2499clos_default_read_sequence(v1stream, v2sequence, v3start, v4end);
  return value0;
 }
}
/* local function STREAM-READ-SEQUENCE                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2502stream_read_sequence(cl_narg narg, cl_object v1stream, cl_object v2sequence, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(ECL_SYM("STREAM-READ-SEQUENCE",1715));
 if (ecl_unlikely(narg>4)) FEwrong_num_arguments(ECL_SYM("STREAM-READ-SEQUENCE",1715));
 {
  cl_object v3start;
  cl_object v4end;
  va_list args; va_start(args,v2sequence);
  {
   int i = 2;
   if (i >= narg) {
    v3start = ecl_make_int8_t(0);
   } else {
    i++;
    v3start = va_arg(args,cl_object);
   }
   if (i >= narg) {
    v4end = ECL_NIL;
   } else {
    i++;
    v4end = va_arg(args,cl_object);
   }
  }
  va_end(args);
  value0 = si_do_read_sequence(v2sequence, v1stream, v3start, v4end);
  return value0;
 }
}
/* local function STREAM-READ-SEQUENCE                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2503stream_read_sequence(cl_narg narg, cl_object v1stream, cl_object v2sequence, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(ECL_SYM("STREAM-READ-SEQUENCE",1715));
 if (ecl_unlikely(narg>4)) FEwrong_num_arguments(ECL_SYM("STREAM-READ-SEQUENCE",1715));
 {
  cl_object v3start;
  cl_object v4end;
  va_list args; va_start(args,v2sequence);
  {
   int i = 2;
   if (i >= narg) {
    v3start = ECL_NIL;
   } else {
    i++;
    v3start = va_arg(args,cl_object);
   }
   if (i >= narg) {
    v4end = ECL_NIL;
   } else {
    i++;
    v4end = va_arg(args,cl_object);
   }
  }
  va_end(args);
  value0 = L2437bug_or_error(v1stream, ECL_SYM("STREAM-READ-SEQUENCE",1715));
  return value0;
 }
}
/* local function STREAM-START-LINE-P                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2504stream_start_line_p(cl_object v1stream)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(ECL_SYM("STREAM-LINE-COLUMN",1706)))->cfun.entry(1, v1stream) /*  STREAM-LINE-COLUMN */;
 value0 = ecl_make_bool((T0)==(ecl_make_int8_t(0)));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2504stream_start_line_p_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-START-LINE-P",1716));
 {
  return LC2504stream_start_line_p(v2stream);
 }
}
/* local function STREAM-FILE-POSITION                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2505stream_file_position(cl_narg narg, cl_object v1stream, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(ECL_SYM("STREAM-FILE-POSITION",1700));
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(ECL_SYM("STREAM-FILE-POSITION",1700));
 {
  cl_object v2position;
  va_list args; va_start(args,v1stream);
  {
   int i = 1;
   if (i >= narg) {
    v2position = ECL_NIL;
   } else {
    i++;
    v2position = va_arg(args,cl_object);
   }
  }
  va_end(args);
  value0 = cl_file_position(2, v1stream, v2position);
  return value0;
 }
}
/* local function STREAM-FILE-POSITION                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2506stream_file_position(cl_narg narg, cl_object v1stream, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(ECL_SYM("STREAM-FILE-POSITION",1700));
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(ECL_SYM("STREAM-FILE-POSITION",1700));
 {
  cl_object v2position;
  va_list args; va_start(args,v1stream);
  {
   int i = 1;
   if (i >= narg) {
    v2position = ECL_NIL;
   } else {
    i++;
    v2position = va_arg(args,cl_object);
   }
  }
  va_end(args);
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* local function STREAM-FILE-LENGTH                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2507stream_file_length(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_file_length(v1stream);
 return value0;
}
static cl_object LC2507stream_file_length_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-FILE-LENGTH",1699));
 {
  return LC2507stream_file_length(v2stream);
 }
}
/* local function STREAM-FILE-LENGTH                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2508stream_file_length(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_error(5, ECL_SYM("TYPE-ERROR",873), ECL_SYM("DATUM",1245), v1stream, ECL_SYM("EXPECTED-TYPE",1263), ECL_SYM("FILE-STREAM",360));
 return value0;
}
static cl_object LC2508stream_file_length_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-FILE-LENGTH",1699));
 {
  return LC2508stream_file_length(v2stream);
 }
}
/* local function STREAM-FILE-STRING-LENGTH                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2509stream_file_string_length(cl_object v1stream, cl_object v2string)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_file_string_length(v1stream, v2string);
 return value0;
}
static cl_object LC2509stream_file_string_length_va(cl_narg narg, cl_object v3stream, cl_object v4string, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(ECL_SYM("STREAM-FILE-STRING-LENGTH",1701));
 {
  return LC2509stream_file_string_length(v3stream, v4string);
 }
}
/* local function STREAM-FILE-STRING-LENGTH                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2510stream_file_string_length(cl_object v1stream, cl_object v2string)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2510stream_file_string_length_va(cl_narg narg, cl_object v3stream, cl_object v4string, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(ECL_SYM("STREAM-FILE-STRING-LENGTH",1701));
 {
  return LC2510stream_file_string_length(v3stream, v4string);
 }
}
/* local function STREAMP                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2511streamp(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2511streamp_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAMP",1690));
 {
  return LC2511streamp(v2stream);
 }
}
/* local function STREAMP                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2512streamp(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2512streamp_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAMP",1690));
 {
  return LC2512streamp(v2stream);
 }
}
/* local function STREAM-WRITE-BYTE                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2513stream_write_byte(cl_object v1stream, cl_object v2integer)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_write_byte(v2integer, v1stream);
 return value0;
}
static cl_object LC2513stream_write_byte_va(cl_narg narg, cl_object v3stream, cl_object v4integer, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(ECL_SYM("STREAM-WRITE-BYTE",1720));
 {
  return LC2513stream_write_byte(v3stream, v4integer);
 }
}
/* local function STREAM-WRITE-BYTE                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2514stream_write_byte(cl_object v1stream, cl_object v2integer)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L2437bug_or_error(v1stream, ECL_SYM("STREAM-WRITE-BYTE",1720));
 return value0;
}
static cl_object LC2514stream_write_byte_va(cl_narg narg, cl_object v3stream, cl_object v4integer, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(ECL_SYM("STREAM-WRITE-BYTE",1720));
 {
  return LC2514stream_write_byte(v3stream, v4integer);
 }
}
/* local function STREAM-WRITE-CHAR                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2515stream_write_char(cl_object v1stream, cl_object v2character)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_write_char(2, v2character, v1stream);
 return value0;
}
static cl_object LC2515stream_write_char_va(cl_narg narg, cl_object v3stream, cl_object v4character, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(ECL_SYM("STREAM-WRITE-CHAR",1721));
 {
  return LC2515stream_write_char(v3stream, v4character);
 }
}
/* local function STREAM-WRITE-CHAR                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2516stream_write_char(cl_object v1stream, cl_object v2character)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L2437bug_or_error(v1stream, ECL_SYM("STREAM-WRITE-CHAR",1721));
 return value0;
}
static cl_object LC2516stream_write_char_va(cl_narg narg, cl_object v3stream, cl_object v4character, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(ECL_SYM("STREAM-WRITE-CHAR",1721));
 {
  return LC2516stream_write_char(v3stream, v4character);
 }
}
/* function definition for CLOS-DEFAULT-WRITE-SEQUENCE                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L2517clos_default_write_sequence(cl_object v1stream, cl_object v2sequence, cl_object v3start, cl_object v4end)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (ecl_unlikely(!(ECL_LISTP(v2sequence) || ECL_VECTORP(v2sequence))))
           FEtype_error_sequence(v2sequence);
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 0;
 {
  bool v5;
  v5 = ECL_FIXNUMP(v3start);
  if (ecl_unlikely(!(v5)))
         FEwrong_type_argument(ECL_SYM("FIXNUM",374),v3start);
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 0;
 }
 {
  cl_fixnum v5;
  cl_object v6;
  {
   cl_object v7;
   value0 = v4end;
   if (value0!=ECL_NIL) {
    goto L8;
   }
   v7 = ecl_make_fixnum(ecl_length(v2sequence));
   goto L6;
L8:;
   v7 = value0;
   goto L6;
L6:;
   {
    bool v8;
    v8 = ECL_FIXNUMP(v7);
    if (ecl_unlikely(!(v8)))
         FEwrong_type_argument(ECL_SYM("FIXNUM",374),v7);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
   }
   v5 = ecl_fixnum(v7);
  }
  v6 = (cl_env_copy->function=ecl_fdefinition(ECL_SYM("STREAM-ELEMENT-TYPE",1697)))->cfun.entry(1, v1stream) /*  STREAM-ELEMENT-TYPE */;
  if ((v6)==(ECL_SYM("CHARACTER",224))) {
   goto L14;
  }
  if (!((v6)==(ECL_SYM("BASE-CHAR",122)))){
   goto L12;
  }
  goto L13;
L14:;
L13:;
  {
   cl_object v7pos;
   v7pos = v3start;
L17:;
   if (!(ecl_greatereq(v7pos,ecl_make_fixnum(v5)))){
    goto L19;
   }
   goto L18;
L19:;
   T0 = ecl_elt(v2sequence,ecl_to_size(v7pos));
   (cl_env_copy->function=ecl_fdefinition(ECL_SYM("STREAM-WRITE-CHAR",1721)))->cfun.entry(2, v1stream, T0) /*  STREAM-WRITE-CHAR */;
   v7pos = ecl_one_plus(v7pos);
   goto L17;
L18:;
   goto L4;
  }
L12:;
  {
   cl_object v8pos;
   v8pos = v3start;
L26:;
   if (!(ecl_greatereq(v8pos,ecl_make_fixnum(v5)))){
    goto L28;
   }
   goto L27;
L28:;
   T0 = ecl_elt(v2sequence,ecl_to_size(v8pos));
   (cl_env_copy->function=ecl_fdefinition(ECL_SYM("STREAM-WRITE-BYTE",1720)))->cfun.entry(2, v1stream, T0) /*  STREAM-WRITE-BYTE */;
   v8pos = ecl_one_plus(v8pos);
   goto L26;
L27:;
  }
 }
L4:;
 value0 = v2sequence;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L2517clos_default_write_sequence_va(cl_narg narg, cl_object v5stream, cl_object v6sequence, cl_object v7start, cl_object v8end, ...)
{
 if (ecl_unlikely(narg!=4)) FEwrong_num_arguments(VV[14]);
 {
  return L2517clos_default_write_sequence(v5stream, v6sequence, v7start, v8end);
 }
}
/* local function STREAM-WRITE-SEQUENCE                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2518stream_write_sequence(cl_narg narg, cl_object v1stream, cl_object v2sequence, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(ECL_SYM("STREAM-WRITE-SEQUENCE",1722));
 if (ecl_unlikely(narg>4)) FEwrong_num_arguments(ECL_SYM("STREAM-WRITE-SEQUENCE",1722));
 {
  cl_object v3start;
  cl_object v4end;
  va_list args; va_start(args,v2sequence);
  {
   int i = 2;
   if (i >= narg) {
    v3start = ecl_make_int8_t(0);
   } else {
    i++;
    v3start = va_arg(args,cl_object);
   }
   if (i >= narg) {
    v4end = ECL_NIL;
   } else {
    i++;
    v4end = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if (!(ECL_STRINGP(v2sequence))){
   goto L3;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(ECL_SYM("STREAM-WRITE-STRING",1723)))->cfun.entry(4, v1stream, v2sequence, v3start, v4end) /*  STREAM-WRITE-STRING */;
  return value0;
L3:;
  value0 = L2517clos_default_write_sequence(v1stream, v2sequence, v3start, v4end);
  return value0;
 }
}
/* local function STREAM-WRITE-SEQUENCE                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2519stream_write_sequence(cl_narg narg, cl_object v1stream, cl_object v2sequence, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(ECL_SYM("STREAM-WRITE-SEQUENCE",1722));
 if (ecl_unlikely(narg>4)) FEwrong_num_arguments(ECL_SYM("STREAM-WRITE-SEQUENCE",1722));
 {
  cl_object v3start;
  cl_object v4end;
  va_list args; va_start(args,v2sequence);
  {
   int i = 2;
   if (i >= narg) {
    v3start = ecl_make_int8_t(0);
   } else {
    i++;
    v3start = va_arg(args,cl_object);
   }
   if (i >= narg) {
    v4end = ECL_NIL;
   } else {
    i++;
    v4end = va_arg(args,cl_object);
   }
  }
  va_end(args);
  value0 = L2517clos_default_write_sequence(v1stream, v2sequence, v3start, v4end);
  return value0;
 }
}
/* local function STREAM-WRITE-SEQUENCE                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2520stream_write_sequence(cl_narg narg, cl_object v1stream, cl_object v2sequence, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(ECL_SYM("STREAM-WRITE-SEQUENCE",1722));
 if (ecl_unlikely(narg>4)) FEwrong_num_arguments(ECL_SYM("STREAM-WRITE-SEQUENCE",1722));
 {
  cl_object v3start;
  cl_object v4end;
  va_list args; va_start(args,v2sequence);
  {
   int i = 2;
   if (i >= narg) {
    v3start = ecl_make_int8_t(0);
   } else {
    i++;
    v3start = va_arg(args,cl_object);
   }
   if (i >= narg) {
    v4end = ECL_NIL;
   } else {
    i++;
    v4end = va_arg(args,cl_object);
   }
  }
  va_end(args);
  value0 = si_do_write_sequence(v2sequence, v1stream, v3start, v4end);
  return value0;
 }
}
/* local function STREAM-WRITE-SEQUENCE                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2521stream_write_sequence(cl_narg narg, cl_object v1stream, cl_object v2sequence, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(ECL_SYM("STREAM-WRITE-SEQUENCE",1722));
 if (ecl_unlikely(narg>4)) FEwrong_num_arguments(ECL_SYM("STREAM-WRITE-SEQUENCE",1722));
 {
  cl_object v3start;
  cl_object v4end;
  va_list args; va_start(args,v2sequence);
  {
   int i = 2;
   if (i >= narg) {
    v3start = ECL_NIL;
   } else {
    i++;
    v3start = va_arg(args,cl_object);
   }
   if (i >= narg) {
    v4end = ECL_NIL;
   } else {
    i++;
    v4end = va_arg(args,cl_object);
   }
  }
  va_end(args);
  value0 = L2437bug_or_error(v1stream, ECL_SYM("STREAM-WRITE-SEQUENCE",1722));
  return value0;
 }
}
/* local function STREAM-WRITE-STRING                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2522stream_write_string(cl_narg narg, cl_object v1stream, cl_object v2string, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(ECL_SYM("STREAM-WRITE-STRING",1723));
 if (ecl_unlikely(narg>4)) FEwrong_num_arguments(ECL_SYM("STREAM-WRITE-STRING",1723));
 {
  cl_object v3start;
  cl_object v4end;
  va_list args; va_start(args,v2string);
  {
   int i = 2;
   if (i >= narg) {
    v3start = ecl_make_int8_t(0);
   } else {
    i++;
    v3start = va_arg(args,cl_object);
    {
     bool v5;
     v5 = ECL_FIXNUMP(v3start);
     if (ecl_unlikely(!(v5)))
         FEwrong_type_argument(ECL_SYM("FIXNUM",374),v3start);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
    }
   }
   if (i >= narg) {
    v4end = ECL_NIL;
   } else {
    i++;
    v4end = va_arg(args,cl_object);
   }
  }
  va_end(args);
  {
   bool v5;
   v5 = ECL_STRINGP(v2string);
   if (ecl_unlikely(!(v5)))
         FEwrong_type_argument(ECL_SYM("STRING",808),v2string);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
  }
  {
   cl_fixnum v5end;
   {
    cl_object v6;
    value0 = v4end;
    if (value0!=ECL_NIL) {
     goto L9;
    }
    v6 = ecl_make_fixnum(ecl_length(v2string));
    goto L7;
L9:;
    v6 = value0;
    goto L7;
L7:;
    {
     bool v7;
     v7 = ECL_FIXNUMP(v6);
     if (ecl_unlikely(!(v7)))
         FEwrong_type_argument(ECL_SYM("FIXNUM",374),v6);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
    }
    v5end = ecl_fixnum(v6);
   }
   {
    cl_fixnum v6pos;
    {
     cl_fixnum v7;
     v7 = ecl_fixnum(v3start);
     {
      cl_fixnum v8;
      v8 = (cl_fixnum)(0);
      v8 = v7;
      if (!((v8)<=(2305843009213693951))){
       goto L23;
      }
      T0 = ecl_make_bool((v8)>=((cl_fixnum)(0)));
      goto L15;
L23:;
      T0 = ECL_NIL;
      goto L15;
      T0 = ECL_NIL;
      goto L15;
     }
L15:;
     if (ecl_unlikely(!((T0)!=ECL_NIL)))
         FEwrong_type_argument(VV[16],ecl_make_fixnum(v7));
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v6pos = v7;
    }
    goto L27;
L26:;
    {
     cl_object v7;
     v7 = v2string;
     T1 = v7;
     {
      cl_fixnum v8;
      v8 = v6pos;
      if (ecl_unlikely((v8)>=(v7)->vector.dim))
           FEwrong_index(ECL_NIL,v7,-1,ecl_make_fixnum(v8),(v7)->vector.dim);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T2 = ecl_make_fixnum(v8);
     }
     T0 = ecl_aref_unsafe(T1,ecl_fixnum(T2));
    }
    (cl_env_copy->function=ecl_fdefinition(ECL_SYM("STREAM-WRITE-CHAR",1721)))->cfun.entry(2, v1stream, T0) /*  STREAM-WRITE-CHAR */;
    {
     cl_object v7;
     v7 = ecl_make_integer((v6pos)+1);
     {
      cl_fixnum v8;
      v8 = (cl_fixnum)(0);
      if (!(ECL_FIXNUMP(v7))){
       goto L44;
      }
      v8 = ecl_fixnum(v7);
      if (!((v8)<=(2305843009213693951))){
       goto L49;
      }
      T0 = ecl_make_bool((v8)>=((cl_fixnum)(0)));
      goto L41;
L49:;
      T0 = ECL_NIL;
      goto L41;
L44:;
      T0 = ECL_NIL;
      goto L41;
     }
L41:;
     if (ecl_unlikely(!((T0)!=ECL_NIL)))
         FEwrong_type_argument(VV[16],v7);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v6pos = ecl_fixnum(v7);
    }
L27:;
    if ((v6pos)>=(v5end)) {
     goto L51;
    }
    goto L26;
L51:;
   }
  }
  value0 = v2string;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* local function STREAM-WRITE-STRING                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2523stream_write_string(cl_narg narg, cl_object v1stream, cl_object v2string, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(ECL_SYM("STREAM-WRITE-STRING",1723));
 if (ecl_unlikely(narg>4)) FEwrong_num_arguments(ECL_SYM("STREAM-WRITE-STRING",1723));
 {
  cl_object v3start;
  cl_object v4end;
  va_list args; va_start(args,v2string);
  {
   int i = 2;
   if (i >= narg) {
    v3start = ecl_make_int8_t(0);
   } else {
    i++;
    v3start = va_arg(args,cl_object);
   }
   if (i >= narg) {
    v4end = ECL_NIL;
   } else {
    i++;
    v4end = va_arg(args,cl_object);
   }
  }
  va_end(args);
  value0 = cl_write_string(6, v2string, v1stream, ECL_SYM("START",1347), v3start, ECL_SYM("END",1256), v4end);
  return value0;
 }
}
/* local function STREAM-WRITE-STRING                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2524stream_write_string(cl_narg narg, cl_object v1stream, cl_object v2string, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(ECL_SYM("STREAM-WRITE-STRING",1723));
 if (ecl_unlikely(narg>4)) FEwrong_num_arguments(ECL_SYM("STREAM-WRITE-STRING",1723));
 {
  cl_object v3start;
  cl_object v4end;
  va_list args; va_start(args,v2string);
  {
   int i = 2;
   if (i >= narg) {
    v3start = ECL_NIL;
   } else {
    i++;
    v3start = va_arg(args,cl_object);
   }
   if (i >= narg) {
    v4end = ECL_NIL;
   } else {
    i++;
    v4end = va_arg(args,cl_object);
   }
  }
  va_end(args);
  value0 = L2437bug_or_error(v1stream, ECL_SYM("STREAM-WRITE-STRING",1723));
  return value0;
 }
}
/* local function STREAM-TERPRI                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2525stream_terpri(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 (cl_env_copy->function=ecl_fdefinition(ECL_SYM("STREAM-WRITE-CHAR",1721)))->cfun.entry(2, v1stream, ECL_CODE_CHAR(10)) /*  STREAM-WRITE-CHAR */;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2525stream_terpri_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-TERPRI",1717));
 {
  return LC2525stream_terpri(v2stream);
 }
}
/* local function STREAM-TERPRI                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2526stream_terpri(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (ecl_terpri(v1stream));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2526stream_terpri_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-TERPRI",1717));
 {
  return LC2526stream_terpri(v2stream);
 }
}
/* local function STREAM-TERPRI                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2527stream_terpri(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L2437bug_or_error(v1stream, ECL_SYM("STREAM-TERPRI",1717));
 return value0;
}
static cl_object LC2527stream_terpri_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("STREAM-TERPRI",1717));
 {
  return LC2527stream_terpri(v2stream);
 }
}
/* local function STREAM-FILE-DESCRIPTOR                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2528stream_file_descriptor(cl_narg narg, cl_object v1stream, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(ECL_SYM("STREAM-FILE-DESCRIPTOR",1698));
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(ECL_SYM("STREAM-FILE-DESCRIPTOR",1698));
 {
  cl_object v2direction;
  va_list args; va_start(args,v1stream);
  {
   int i = 1;
   if (i >= narg) {
    v2direction = ECL_SYM("INPUT",1289);
   } else {
    i++;
    v2direction = va_arg(args,cl_object);
   }
  }
  va_end(args);
  {
   cl_object v3;                                  /*  PREDICATE               */
   cl_object v4;                                  /*  KIND                    */
   if (!((v2direction)==(ECL_SYM("INPUT",1289)))){
    goto L3;
   }
   cl_env_copy->nvalues = 2;
   cl_env_copy->values[1] = VV[19];
   cl_env_copy->values[0] = ECL_SYM("INPUT-STREAM-P",1691);
   value0 = cl_env_copy->values[0];
   goto L2;
L3:;
   if (!((v2direction)==(ECL_SYM("OUTPUT",1319)))){
    goto L5;
   }
   cl_env_copy->nvalues = 2;
   cl_env_copy->values[1] = VV[20];
   cl_env_copy->values[0] = ECL_SYM("OUTPUT-STREAM-P",1692);
   value0 = cl_env_copy->values[0];
   goto L2;
L5:;
   T0 = ecl_list1(v2direction);
   value0 = cl_error(9, ECL_SYM("SIMPLE-TYPE-ERROR",776), ECL_SYM("FORMAT-CONTROL",1272), VV[21], ECL_SYM("FORMAT-ARGUMENTS",1271), T0, ECL_SYM("DATUM",1245), v2direction, ECL_SYM("EXPECTED-TYPE",1263), VV[22]);
L2:;
   {
    const int v5 = cl_env_copy->nvalues;
    v3 = value0;
    cl_object v6;
    v6 = (v5<=1)? ECL_NIL : cl_env_copy->values[1];
    v4 = v6;
   }
   if (ecl_function_dispatch(cl_env_copy,v3)(1, v1stream)!=ECL_NIL) {
    goto L7;
   }
   T0 = cl_list(3, v4, v1stream, v2direction);
   T1 = cl_list(2, ECL_SYM("SATISFIES",738), v3);
   value0 = cl_error(9, ECL_SYM("SIMPLE-TYPE-ERROR",776), ECL_SYM("FORMAT-CONTROL",1272), VV[23], ECL_SYM("FORMAT-ARGUMENTS",1271), T0, ECL_SYM("DATUM",1245), v1stream, ECL_SYM("EXPECTED-TYPE",1263), T1);
   return value0;
L7:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* local function STREAM-FILE-DESCRIPTOR                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2529stream_file_descriptor(cl_narg narg, cl_object v1stream, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(ECL_SYM("STREAM-FILE-DESCRIPTOR",1698));
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(ECL_SYM("STREAM-FILE-DESCRIPTOR",1698));
 {
  cl_object v2direction;
  va_list args; va_start(args,v1stream);
  {
   int i = 1;
   if (i >= narg) {
    v2direction = ECL_NIL;
   } else {
    i++;
    v2direction = va_arg(args,cl_object);
   }
  }
  va_end(args);
  value0 = L2437bug_or_error(v1stream, ECL_SYM("STREAM-FILE-DESCRIPTOR",1698));
  return value0;
 }
}
/* local function STREAM-FILE-DESCRIPTOR                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2530stream_file_descriptor(cl_narg narg, cl_object v1stream, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(ECL_SYM("STREAM-FILE-DESCRIPTOR",1698));
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(ECL_SYM("STREAM-FILE-DESCRIPTOR",1698));
 {
  cl_object v2direction;
  va_list args; va_start(args,v1stream);
  {
   int i = 1;
   if (i >= narg) {
    v2direction = ECL_SYM("INPUT",1289);
   } else {
    i++;
    v2direction = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if (!((v2direction)==(ECL_SYM("INPUT",1289)))){
   goto L3;
  }
  T0 = cl_two_way_stream_input_stream(v1stream);
  goto L2;
L3:;
  if (!((v2direction)==(ECL_SYM("OUTPUT",1319)))){
   goto L5;
  }
  T0 = cl_two_way_stream_output_stream(v1stream);
  goto L2;
L5:;
  T0 = ECL_NIL;
L2:;
  value0 = (cl_env_copy->function=ecl_fdefinition(ECL_SYM("STREAM-FILE-DESCRIPTOR",1698)))->cfun.entry(2, T0, v2direction) /*  STREAM-FILE-DESCRIPTOR */;
  return value0;
 }
}
/* local function STREAM-FILE-DESCRIPTOR                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2531stream_file_descriptor(cl_narg narg, cl_object v1stream, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(ECL_SYM("STREAM-FILE-DESCRIPTOR",1698));
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(ECL_SYM("STREAM-FILE-DESCRIPTOR",1698));
 {
  cl_object v2direction;
  va_list args; va_start(args,v1stream);
  {
   int i = 1;
   if (i >= narg) {
    v2direction = ECL_SYM("INPUT",1289);
   } else {
    i++;
    v2direction = va_arg(args,cl_object);
   }
  }
  va_end(args);
  value0 = si_file_stream_fd(v1stream);
  return value0;
 }
}
/* local function PATHNAME                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2532pathname(cl_object v1pathspec)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_pathname(v1pathspec);
 return value0;
}
static cl_object LC2532pathname_va(cl_narg narg, cl_object v2pathspec, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("PATHNAME",1687));
 {
  return LC2532pathname(v2pathspec);
 }
}
/* local function PATHNAME                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2533pathname(cl_object v1pathspec)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = v1pathspec;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2533pathname_va(cl_narg narg, cl_object v2pathspec, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("PATHNAME",1687));
 {
  return LC2533pathname(v2pathspec);
 }
}
/* local function PATHNAME                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2534pathname(cl_object v1pathspec)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_pathname(v1pathspec);
 return value0;
}
static cl_object LC2534pathname_va(cl_narg narg, cl_object v2pathspec, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("PATHNAME",1687));
 {
  return LC2534pathname(v2pathspec);
 }
}
/* local function PATHNAME                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2535pathname(cl_object v1pathspec)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_error(5, ECL_SYM("TYPE-ERROR",873), ECL_SYM("DATUM",1245), v1pathspec, ECL_SYM("EXPECTED-TYPE",1263), VV[24]);
 return value0;
}
static cl_object LC2535pathname_va(cl_narg narg, cl_object v2pathspec, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("PATHNAME",1687));
 {
  return LC2535pathname(v2pathspec);
 }
}
/* local function TRUENAME                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2536truename(cl_object v1filespec)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_truename(v1filespec);
 return value0;
}
static cl_object LC2536truename_va(cl_narg narg, cl_object v2filespec, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("TRUENAME",1688));
 {
  return LC2536truename(v2filespec);
 }
}
/* local function TRUENAME                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2537truename(cl_object v1filespec)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_truename(v1filespec);
 return value0;
}
static cl_object LC2537truename_va(cl_narg narg, cl_object v2filespec, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("TRUENAME",1688));
 {
  return LC2537truename(v2filespec);
 }
}
/* local function TRUENAME                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2538truename(cl_object v1filespec)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_truename(v1filespec);
 return value0;
}
static cl_object LC2538truename_va(cl_narg narg, cl_object v2filespec, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("TRUENAME",1688));
 {
  return LC2538truename(v2filespec);
 }
}
/* local function TRUENAME                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2539truename(cl_object v1filespec)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_error(5, ECL_SYM("TYPE-ERROR",873), ECL_SYM("DATUM",1245), v1filespec, ECL_SYM("EXPECTED-TYPE",1263), VV[24]);
 return value0;
}
static cl_object LC2539truename_va(cl_narg narg, cl_object v2filespec, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("TRUENAME",1688));
 {
  return LC2539truename(v2filespec);
 }
}
/* function definition for %REDEFINE-CL-FUNCTIONS                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L2540_redefine_cl_functions(cl_object v1cl_symbol, cl_object v2gray_symbol, cl_object v3gray_package)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_fdefinition(v1cl_symbol);
 if (si_of_class_p(2, T0, ECL_SYM("GENERIC-FUNCTION",949))!=ECL_NIL) {
  goto L2;
 }
 {
  cl_object v4gf;
  v4gf = cl_fdefinition(v2gray_symbol);
  si_fset(2, v1cl_symbol, v4gf);
  T0 = ecl_symbol_name(v1cl_symbol);
  T1 = ecl_symbol_name(v2gray_symbol);
  if (!(ecl_string_eq(T0,T1))){
   goto L6;
  }
  cl_unintern(2, v2gray_symbol, v3gray_package);
  cl_import(2, v1cl_symbol, v3gray_package);
  cl_export(2, v1cl_symbol, v3gray_package);
L6:;
  value0 = (cl_env_copy->function=ECL_CONS_CAR(VV[42]))->cfun.entry(3, v1cl_symbol, v4gf, ECL_SYM("NAME",1611)) /*  (SETF SLOT-VALUE) */;
  return value0;
 }
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L2540_redefine_cl_functions_va(cl_narg narg, cl_object v5cl_symbol, cl_object v6gray_symbol, cl_object v7gray_package, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[28]);
 {
  return L2540_redefine_cl_functions(v5cl_symbol, v6gray_symbol, v7gray_package);
 }
}
/* function definition for REDEFINE-CL-FUNCTIONS                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L2541redefine_cl_functions()
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  cl_object v2;
  v1 = si_package_lock(VV[26], ECL_NIL);
  v2 = cl_find_package(VV[0]);
  {
   cl_object v3cl_symbol;
   cl_object v4;
   v3cl_symbol = ECL_NIL;
   v4 = VV[27];
   {
    cl_object v5gray_symbol;
    v5gray_symbol = ECL_NIL;
L8:;
    v3cl_symbol = ECL_CONS_CAR(v4);
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v4);
     if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v4 = v6;
    }
    T0 = ecl_symbol_name(v3cl_symbol);
    v5gray_symbol = cl_find_symbol(2, T0, v2);
    L2540_redefine_cl_functions(v3cl_symbol, v5gray_symbol, v2);
    if (!(ecl_endp(v4))){
     goto L19;
    }
    goto L9;
L19:;
    goto L8;
L9:;
   }
  }
  L2540_redefine_cl_functions(ECL_SYM("FILE-POSITION",359), ECL_SYM("STREAM-FILE-POSITION",1700), v2);
  L2540_redefine_cl_functions(ECL_SYM("FILE-LENGTH",357), ECL_SYM("STREAM-FILE-LENGTH",1699), v2);
  si_package_lock(VV[26], v1);
  cl_provide(VV[32]);
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L2541redefine_cl_functions_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[31]);
 {
  return L2541redefine_cl_functions();
 }
}
/* local function LAMBDA199                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2542__lambda199(cl_object v1module)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(cl_string_equal(2, v1module, VV[36]))){
  goto L2;
 }
 L2541redefine_cl_functions();
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2542__lambda199_va(cl_narg narg, cl_object v2module, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[35]);
 {
  return LC2542__lambda199(v2module);
 }
}
#include "clos/streams.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _eclT9LBgSoBij8q9_U180M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:CLOS;STREAMS.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_eclT9LBgSoBij8q9_U180M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
 {
  cl_object T0, T1;
  cl_object volatile env0 = ECL_NIL;
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(VV[0]);
  cl_import(1, ECL_SYM("ANSI-STREAM",1878));
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("STREAM-ADVANCE-TO-COLUMN",1694), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[0], ECL_SYM("DOCUMENTATION",1253), VVtemp[1]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("STREAM-CLEAR-INPUT",1695), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[2], ECL_SYM("DOCUMENTATION",1253), VVtemp[3]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("STREAM-CLEAR-OUTPUT",1696), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[2], ECL_SYM("DOCUMENTATION",1253), VVtemp[4]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("CLOSE",1689), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[5], ECL_SYM("DOCUMENTATION",1253), VVtemp[6]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("STREAM-ELEMENT-TYPE",1697), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[2], ECL_SYM("DOCUMENTATION",1253), VVtemp[7]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("STREAM-FINISH-OUTPUT",1702), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[2], ECL_SYM("DOCUMENTATION",1253), VVtemp[8]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("STREAM-FORCE-OUTPUT",1703), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[2], ECL_SYM("DOCUMENTATION",1253), VVtemp[9]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("STREAM-FRESH-LINE",1704), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[2], ECL_SYM("DOCUMENTATION",1253), VVtemp[10]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("INPUT-STREAM-P",1691), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[2], ECL_SYM("DOCUMENTATION",1253), VVtemp[11]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[2], VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[2], ECL_SYM("DOCUMENTATION",1253), VVtemp[12]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("STREAM-INTERACTIVE-P",1705), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[2], ECL_SYM("DOCUMENTATION",1253), VVtemp[13]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("STREAM-LINE-COLUMN",1706), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[2], ECL_SYM("DOCUMENTATION",1253), VVtemp[14]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("STREAM-LINE-LENGTH",1707), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[2], ECL_SYM("DOCUMENTATION",1253), VVtemp[15]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("STREAM-LISTEN",1708), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[2], ECL_SYM("DOCUMENTATION",1253), VVtemp[16]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("OPEN-STREAM-P",1693), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[2], ECL_SYM("DOCUMENTATION",1253), VVtemp[17]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("OUTPUT-STREAM-P",1692), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[2], ECL_SYM("DOCUMENTATION",1253), VVtemp[18]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("STREAM-PEEK-BYTE",1709), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[2], ECL_SYM("DOCUMENTATION",1253), VVtemp[19]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("STREAM-PEEK-CHAR",1710), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[2], ECL_SYM("DOCUMENTATION",1253), VVtemp[20]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("STREAM-READ-BYTE",1711), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[2], ECL_SYM("DOCUMENTATION",1253), VVtemp[21]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("STREAM-READ-CHAR",1712), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[2], ECL_SYM("DOCUMENTATION",1253), VVtemp[22]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("STREAM-READ-CHAR-NO-HANG",1713), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[2], ECL_SYM("DOCUMENTATION",1253), VVtemp[23]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("STREAM-READ-LINE",1714), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[2], ECL_SYM("DOCUMENTATION",1253), VVtemp[24]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("STREAM-READ-SEQUENCE",1715), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[25], ECL_SYM("DOCUMENTATION",1253), VVtemp[26]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("STREAM-START-LINE-P",1716), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[2], ECL_SYM("DOCUMENTATION",1253), VVtemp[27]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("STREAM-TERPRI",1717), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[2], ECL_SYM("DOCUMENTATION",1253), VVtemp[28]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("STREAM-UNREAD-BYTE",1718), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[29], ECL_SYM("DOCUMENTATION",1253), VVtemp[30]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("STREAM-UNREAD-CHAR",1719), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[31], ECL_SYM("DOCUMENTATION",1253), VVtemp[32]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("STREAM-WRITE-BYTE",1720), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[33], ECL_SYM("DOCUMENTATION",1253), VVtemp[34]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("STREAM-WRITE-CHAR",1721), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[31], ECL_SYM("DOCUMENTATION",1253), VVtemp[35]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("STREAM-WRITE-STRING",1723), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[36], ECL_SYM("DOCUMENTATION",1253), VVtemp[37]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("STREAM-WRITE-SEQUENCE",1722), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[25], ECL_SYM("DOCUMENTATION",1253), VVtemp[38]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("STREAM-FILE-POSITION",1700), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[39], ECL_SYM("DOCUMENTATION",1253), VVtemp[40]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("STREAM-FILE-LENGTH",1699), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[2], ECL_SYM("DOCUMENTATION",1253), VVtemp[41]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("STREAM-FILE-STRING-LENGTH",1701), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[42], ECL_SYM("DOCUMENTATION",1253), VVtemp[43]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("STREAM-FILE-DESCRIPTOR",1698), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[44], ECL_SYM("DOCUMENTATION",1253), VVtemp[45]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("PATHNAME",1687), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[46], ECL_SYM("DOCUMENTATION",1253), VVtemp[47]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, ECL_SYM("TRUENAME",1688), VV[1], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[46], ECL_SYM("DOCUMENTATION",1253), VVtemp[48]) /*  ENSURE-GENERIC-FUNCTION */;
  ecl_bds_bind(cl_env_copy,VV[3],ECL_SYM("MAP-DEPENDENTS",1605)); /*  *CLOS-BOOTED* */
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[51]);
  clos_load_defclass(ECL_SYM("FUNDAMENTAL-STREAM",1724), VVtemp[49], VVtemp[50], T0);
  ecl_bds_unwind1(cl_env_copy);
  clos_load_defclass(ECL_SYM("FUNDAMENTAL-INPUT-STREAM",1725), VVtemp[52], ECL_NIL, ECL_NIL);
  clos_load_defclass(ECL_SYM("FUNDAMENTAL-OUTPUT-STREAM",1726), VVtemp[52], ECL_NIL, ECL_NIL);
  clos_load_defclass(ECL_SYM("FUNDAMENTAL-CHARACTER-STREAM",1727), VVtemp[52], ECL_NIL, ECL_NIL);
  clos_load_defclass(ECL_SYM("FUNDAMENTAL-BINARY-STREAM",1728), VVtemp[52], ECL_NIL, ECL_NIL);
  clos_load_defclass(ECL_SYM("FUNDAMENTAL-CHARACTER-INPUT-STREAM",1729), VVtemp[53], ECL_NIL, ECL_NIL);
  clos_load_defclass(ECL_SYM("FUNDAMENTAL-CHARACTER-OUTPUT-STREAM",1730), VVtemp[54], ECL_NIL, ECL_NIL);
  clos_load_defclass(ECL_SYM("FUNDAMENTAL-BINARY-INPUT-STREAM",1731), VVtemp[55], ECL_NIL, ECL_NIL);
  clos_load_defclass(ECL_SYM("FUNDAMENTAL-BINARY-OUTPUT-STREAM",1732), VVtemp[56], ECL_NIL, ECL_NIL);
  (void)0; /* No entry created for BUG-OR-ERROR */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2438stream_advance_to_column_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-ADVANCE-TO-COLUMN",1694), ECL_NIL, VVtemp[57], VVtemp[0], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2439stream_clear_input_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-CLEAR-INPUT",1695), ECL_NIL, VVtemp[58], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2440stream_clear_input_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-CLEAR-INPUT",1695), ECL_NIL, VVtemp[59], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2441stream_clear_input_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-CLEAR-INPUT",1695), ECL_NIL, VVtemp[60], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2442stream_clear_output_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-CLEAR-OUTPUT",1696), ECL_NIL, VVtemp[61], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2443stream_clear_output_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-CLEAR-OUTPUT",1696), ECL_NIL, VVtemp[59], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2444stream_clear_output_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-CLEAR-OUTPUT",1696), ECL_NIL, VVtemp[60], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2445close,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("CLOSE",1689), ECL_NIL, VVtemp[52], VVtemp[5], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2446close,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("CLOSE",1689), ECL_NIL, VVtemp[59], VVtemp[5], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2447close,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("CLOSE",1689), ECL_NIL, VVtemp[2], VVtemp[5], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2448stream_element_type_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-ELEMENT-TYPE",1697), ECL_NIL, VVtemp[62], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2449stream_element_type_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-ELEMENT-TYPE",1697), ECL_NIL, VVtemp[59], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2450stream_element_type_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-ELEMENT-TYPE",1697), ECL_NIL, VVtemp[60], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2451stream_finish_output_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-FINISH-OUTPUT",1702), ECL_NIL, VVtemp[61], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2452stream_finish_output_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-FINISH-OUTPUT",1702), ECL_NIL, VVtemp[59], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2453stream_finish_output_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-FINISH-OUTPUT",1702), ECL_NIL, VVtemp[60], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2454stream_force_output_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-FORCE-OUTPUT",1703), ECL_NIL, VVtemp[61], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2455stream_force_output_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-FORCE-OUTPUT",1703), ECL_NIL, VVtemp[59], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2456stream_force_output_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-FORCE-OUTPUT",1703), ECL_NIL, VVtemp[60], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2457stream_fresh_line_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-FRESH-LINE",1704), ECL_NIL, VVtemp[63], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2458stream_fresh_line_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-FRESH-LINE",1704), ECL_NIL, VVtemp[59], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2459input_stream_p_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("INPUT-STREAM-P",1691), ECL_NIL, VVtemp[52], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2460input_stream_p_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("INPUT-STREAM-P",1691), ECL_NIL, VVtemp[64], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2461input_stream_p_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("INPUT-STREAM-P",1691), ECL_NIL, VVtemp[59], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2462input_stream_p_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("INPUT-STREAM-P",1691), ECL_NIL, VVtemp[60], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2463stream_interactive_p_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-INTERACTIVE-P",1705), ECL_NIL, VVtemp[52], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2464stream_interactive_p_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-INTERACTIVE-P",1705), ECL_NIL, VVtemp[59], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2465stream_interactive_p_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-INTERACTIVE-P",1705), ECL_NIL, VVtemp[60], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2466stream_line_column_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-LINE-COLUMN",1706), ECL_NIL, VVtemp[63], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2467stream_line_length_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-LINE-LENGTH",1707), ECL_NIL, VVtemp[63], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2468stream_line_length_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-LINE-LENGTH",1707), ECL_NIL, VVtemp[59], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2469stream_line_length_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-LINE-LENGTH",1707), ECL_NIL, VVtemp[60], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2470stream_listen_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-LISTEN",1708), ECL_NIL, VVtemp[58], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2471stream_listen_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-LISTEN",1708), ECL_NIL, VVtemp[59], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2472stream_listen_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-LISTEN",1708), ECL_NIL, VVtemp[60], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2473open_stream_p_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("OPEN-STREAM-P",1693), ECL_NIL, VVtemp[59], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2474open_stream_p_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("OPEN-STREAM-P",1693), ECL_NIL, VVtemp[60], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2475output_stream_p_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("OUTPUT-STREAM-P",1692), ECL_NIL, VVtemp[52], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2476output_stream_p_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("OUTPUT-STREAM-P",1692), ECL_NIL, VVtemp[61], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2477output_stream_p_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("OUTPUT-STREAM-P",1692), ECL_NIL, VVtemp[59], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2478output_stream_p_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("OUTPUT-STREAM-P",1692), ECL_NIL, VVtemp[60], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2479stream_peek_byte_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-PEEK-BYTE",1709), ECL_NIL, VVtemp[65], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2480stream_peek_byte_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-PEEK-BYTE",1709), ECL_NIL, VVtemp[59], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2481stream_peek_byte_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-PEEK-BYTE",1709), ECL_NIL, VVtemp[60], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2482stream_peek_char_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-PEEK-CHAR",1710), ECL_NIL, VVtemp[58], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2483stream_peek_char_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-PEEK-CHAR",1710), ECL_NIL, VVtemp[59], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2484stream_peek_char_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-PEEK-CHAR",1710), ECL_NIL, VVtemp[60], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2485stream_read_byte_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-READ-BYTE",1711), ECL_NIL, VVtemp[59], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2486stream_read_byte_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-READ-BYTE",1711), ECL_NIL, VVtemp[60], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2487stream_read_char_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-READ-CHAR",1712), ECL_NIL, VVtemp[59], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2488stream_read_char_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-READ-CHAR",1712), ECL_NIL, VVtemp[60], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2489stream_unread_byte_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-UNREAD-BYTE",1718), ECL_NIL, VVtemp[66], VVtemp[29], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2490stream_unread_byte_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-UNREAD-BYTE",1718), ECL_NIL, VVtemp[67], VVtemp[29], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2491stream_unread_char_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-UNREAD-CHAR",1719), ECL_NIL, VVtemp[66], VVtemp[31], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2492stream_unread_char_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-UNREAD-CHAR",1719), ECL_NIL, VVtemp[67], VVtemp[31], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2493stream_read_char_no_hang_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-READ-CHAR-NO-HANG",1713), ECL_NIL, VVtemp[58], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2494stream_read_char_no_hang_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-READ-CHAR-NO-HANG",1713), ECL_NIL, VVtemp[59], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2495stream_read_char_no_hang_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-READ-CHAR-NO-HANG",1713), ECL_NIL, VVtemp[60], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2496stream_read_line_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-READ-LINE",1714), ECL_NIL, VVtemp[58], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2497stream_read_line_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-READ-LINE",1714), ECL_NIL, VVtemp[59], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2498stream_read_line_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-READ-LINE",1714), ECL_NIL, VVtemp[60], VVtemp[2], T0);
  ecl_cmp_defun(VV[37]);                          /*  CLOS-DEFAULT-READ-SEQUENCE */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2500stream_read_sequence,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-READ-SEQUENCE",1715), ECL_NIL, VVtemp[68], VVtemp[69], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2501stream_read_sequence,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-READ-SEQUENCE",1715), ECL_NIL, VVtemp[70], VVtemp[69], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2502stream_read_sequence,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-READ-SEQUENCE",1715), ECL_NIL, VVtemp[66], VVtemp[69], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2503stream_read_sequence,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-READ-SEQUENCE",1715), ECL_NIL, VVtemp[67], VVtemp[25], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2504stream_start_line_p_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-START-LINE-P",1716), ECL_NIL, VVtemp[63], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2505stream_file_position,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-FILE-POSITION",1700), ECL_NIL, VVtemp[59], VVtemp[39], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2506stream_file_position,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-FILE-POSITION",1700), ECL_NIL, VVtemp[60], VVtemp[39], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2507stream_file_length_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-FILE-LENGTH",1699), ECL_NIL, VVtemp[59], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2508stream_file_length_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-FILE-LENGTH",1699), ECL_NIL, VVtemp[60], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2509stream_file_string_length_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-FILE-STRING-LENGTH",1701), ECL_NIL, VVtemp[66], VVtemp[42], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2510stream_file_string_length_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-FILE-STRING-LENGTH",1701), ECL_NIL, VVtemp[57], VVtemp[42], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2511streamp_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAMP",1690), ECL_NIL, VVtemp[2], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2512streamp_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAMP",1690), ECL_NIL, VVtemp[60], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2513stream_write_byte_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-WRITE-BYTE",1720), ECL_NIL, VVtemp[66], VVtemp[33], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2514stream_write_byte_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-WRITE-BYTE",1720), ECL_NIL, VVtemp[67], VVtemp[33], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2515stream_write_char_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-WRITE-CHAR",1721), ECL_NIL, VVtemp[66], VVtemp[31], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2516stream_write_char_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-WRITE-CHAR",1721), ECL_NIL, VVtemp[67], VVtemp[31], T0);
  ecl_cmp_defun(VV[38]);                          /*  CLOS-DEFAULT-WRITE-SEQUENCE */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2518stream_write_sequence,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-WRITE-SEQUENCE",1722), ECL_NIL, VVtemp[57], VVtemp[71], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2519stream_write_sequence,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-WRITE-SEQUENCE",1722), ECL_NIL, VVtemp[72], VVtemp[71], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2520stream_write_sequence,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-WRITE-SEQUENCE",1722), ECL_NIL, VVtemp[66], VVtemp[71], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2521stream_write_sequence,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-WRITE-SEQUENCE",1722), ECL_NIL, VVtemp[67], VVtemp[25], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2522stream_write_string,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-WRITE-STRING",1723), ECL_NIL, VVtemp[57], VVtemp[73], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2523stream_write_string,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-WRITE-STRING",1723), ECL_NIL, VVtemp[66], VVtemp[73], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2524stream_write_string,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-WRITE-STRING",1723), ECL_NIL, VVtemp[67], VVtemp[36], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2525stream_terpri_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-TERPRI",1717), ECL_NIL, VVtemp[63], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2526stream_terpri_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-TERPRI",1717), ECL_NIL, VVtemp[59], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2527stream_terpri_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-TERPRI",1717), ECL_NIL, VVtemp[60], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2528stream_file_descriptor,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-FILE-DESCRIPTOR",1698), VVtemp[74], VVtemp[60], VVtemp[75], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2529stream_file_descriptor,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-FILE-DESCRIPTOR",1698), ECL_NIL, VVtemp[60], VVtemp[44], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2530stream_file_descriptor,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-FILE-DESCRIPTOR",1698), ECL_NIL, VVtemp[76], VVtemp[75], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2531stream_file_descriptor,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-FILE-DESCRIPTOR",1698), ECL_NIL, VVtemp[77], VVtemp[75], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2532pathname_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("PATHNAME",1687), ECL_NIL, VVtemp[78], VVtemp[46], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2533pathname_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("PATHNAME",1687), ECL_NIL, VVtemp[79], VVtemp[46], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2534pathname_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("PATHNAME",1687), ECL_NIL, VVtemp[59], VVtemp[46], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2535pathname_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("PATHNAME",1687), ECL_NIL, VVtemp[60], VVtemp[46], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2536truename_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("TRUENAME",1688), ECL_NIL, VVtemp[78], VVtemp[80], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2537truename_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("TRUENAME",1688), ECL_NIL, VVtemp[79], VVtemp[80], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2538truename_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("TRUENAME",1688), ECL_NIL, VVtemp[59], VVtemp[80], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2539truename_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("TRUENAME",1688), ECL_NIL, VVtemp[60], VVtemp[80], T0);
  {
   cl_object v1p;
   v1p = cl_find_package(VV[0]);
   cl_export(2, VVtemp[81], v1p);
   {
    cl_object v2;
    cl_object v3;
    cl_object v4s;
    T0 = cl_find_package(VV[26]);
    v2 = si_packages_iterator(T0, VVtemp[82], ECL_T);
    v3 = ECL_NIL;
    v4s = ECL_NIL;
    goto L276;
L275:;
    value0 = ecl_function_dispatch(cl_env_copy,v2)(0);
    {
     const int v5 = cl_env_copy->nvalues;
     v3 = value0;
     cl_object v6;
     v6 = (v5<=1)? ECL_NIL : cl_env_copy->values[1];
     v4s = v6;
    }
    if (v3!=ECL_NIL) {
     goto L280;
    }
    goto L268;
L280:;
    {
     cl_object v5;
     cl_object v6;
     v5 = v4s;
     v6 = VV[27];
     if (ecl_memql(v5,v6)!=ECL_NIL) {
      goto L282;
     }
    }
    cl_export(2, v4s, v1p);
L282:;
L276:;
    goto L275;
   }
  }
L268:;
  ecl_cmp_defun(VV[39]);                          /*  %REDEFINE-CL-FUNCTIONS  */
  ecl_cmp_defun(VV[40]);                          /*  REDEFINE-CL-FUNCTIONS   */
  T0 = cl_adjoin(2, VV[34], ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36)));
  ecl_cmp_setq(cl_env_copy,ECL_SYM("*FEATURES*",36),T0);
  {
   cl_object volatile v5;
   v5 = ecl_make_cfun_va((cl_objectfn)LC2542__lambda199_va,ECL_NIL,Cblock,1);
   T0 = v5;
  }
  T1 = cl_adjoin(2, T0, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*MODULE-PROVIDER-FUNCTIONS*",44)));
  ecl_cmp_setq(cl_env_copy,ECL_SYM("*MODULE-PROVIDER-FUNCTIONS*",44),T1);
  T0 = ECL_T;
  ecl_cmp_setq(cl_env_copy,VV[3],T0);
 }
}
